@@ -19,10 +19,10 @@ import requests
 from _pytest.tmpdir import TempPathFactory
 
 from pytest_docker_git_fixtures import (
-    DockerGITCerts,
-    DockerGITInsecure,
-    DockerGITSecure,
-    DOCKER_GIT_SERVICE_PATTERN,
+    GITCerts,
+    GITInsecure,
+    GITSecure,
+    GIT_SERVICE_PATTERN,
 )
 from pytest_docker_git_fixtures.fixtures import _get_create_repo, _get_mirror_repo
 from pytest_docker_git_fixtures.utils import git_askpass_script
@@ -32,7 +32,7 @@ LOGGER = logging.getLogger(__name__)
 
 # Override fixture for testing
 @pytest.fixture(scope="session")
-def pdrf_scale_factor() -> int:
+def pdgf_scale_factor() -> int:
     """Provides the number enumerated instances to be instantiated."""
     return 4
 
@@ -42,187 +42,149 @@ def no_duplicates(lst: List) -> bool:
     return len(lst) == len(set(lst))
 
 
-def test_docker_compose_insecure(docker_compose_insecure: Path):
-    """Test that the embedded docker-compose for insecure scms can be copied to a temporary file."""
-    service_name = DOCKER_GIT_SERVICE_PATTERN.format("insecure", 0)
-    assert service_name in docker_compose_insecure.read_text()
-
-
-def test_docker_compose_insecure_list(
-    docker_compose_insecure_list: List[Path], pdrf_scale_factor: int
-):
-    """Test that the embedded docker-compose for insecure scms can be copied to a temporary file."""
-    for i in range(pdrf_scale_factor):
-        service_name = DOCKER_GIT_SERVICE_PATTERN.format("insecure", i)
-        assert service_name in docker_compose_insecure_list[i].read_text()
-    assert no_duplicates(docker_compose_insecure_list)
-
-
-def test_docker_compose_secure(docker_compose_secure: Path):
-    """Test that the embedded docker-compose for secure scms can be copied to a temporary file."""
-    service_name = DOCKER_GIT_SERVICE_PATTERN.format("secure", 0)
-    assert service_name in docker_compose_secure.read_text()
-
-
-def test_docker_compose_secure_list(
-    docker_compose_secure_list: List[Path], pdrf_scale_factor: int
-):
-    """Test that the embedded docker-compose for secure scms can be copied to a temporary file."""
-    for i in range(pdrf_scale_factor):
-        service_name = DOCKER_GIT_SERVICE_PATTERN.format("secure", i)
-        assert service_name in docker_compose_secure_list[i].read_text()
-    assert no_duplicates(docker_compose_secure_list)
-
-
-def test_docker_git_auth_header(
-    docker_git_auth_header: Dict[str, str],
-    docker_git_password: str,
-    docker_git_username: str,
+def test_git_auth_header(
+    git_auth_header: Dict[str, str],
+    git_password: str,
+    git_username: str,
 ):
     """Test that an HTTP basic authentication header can be provided."""
-    assert "Authorization" in docker_git_auth_header
+    assert "Authorization" in git_auth_header
     string = b64decode(
-        docker_git_auth_header["Authorization"].split()[1].encode("utf-8")
+        git_auth_header["Authorization"].split()[1].encode("utf-8")
     ).decode("utf-8")
-    assert docker_git_password in string
-    assert docker_git_username in string
+    assert git_password in string
+    assert git_username in string
 
 
-def test_docker_git_auth_header_list(
-    docker_git_auth_header_list: List[Dict[str, str]],
-    docker_git_password_list: List[str],
-    docker_git_username_list: List[str],
-    pdrf_scale_factor: int,
+def test_git_auth_header_list(
+    git_auth_header_list: List[Dict[str, str]],
+    git_password_list: List[str],
+    git_username_list: List[str],
+    pdgf_scale_factor: int,
 ):
     """Test that an HTTP basic authentication header can be provided."""
-    for i in range(pdrf_scale_factor):
-        assert "Authorization" in docker_git_auth_header_list[i]
+    for i in range(pdgf_scale_factor):
+        assert "Authorization" in git_auth_header_list[i]
         string = b64decode(
-            docker_git_auth_header_list[i]["Authorization"].split()[1].encode("utf-8")
+            git_auth_header_list[i]["Authorization"].split()[1].encode("utf-8")
         ).decode("utf-8")
-        assert docker_git_password_list[i] in string
-        assert docker_git_username_list[i] in string
-    assert no_duplicates([str(i) for i in docker_git_auth_header_list])
-    assert no_duplicates(docker_git_password_list)
-    assert no_duplicates(docker_git_username_list)
+        assert git_password_list[i] in string
+        assert git_username_list[i] in string
+    assert no_duplicates([str(i) for i in git_auth_header_list])
+    assert no_duplicates(git_password_list)
+    assert no_duplicates(git_username_list)
 
 
-def test_docker_git_cacerts(docker_git_cacerts: Path, docker_git_certs: DockerGITCerts):
+def test_git_cacerts(git_cacerts: Path, git_certs: GITCerts):
     """Test that a temporary CA certificate trust store can be provided."""
-    assert docker_git_cacerts.exists()
-    cacerts = docker_git_cacerts.read_text("utf-8")
+    assert git_cacerts.exists()
+    cacerts = git_cacerts.read_text("utf-8")
 
-    ca_cert = docker_git_certs.ca_certificate.read_text("utf-8")
+    ca_cert = git_certs.ca_certificate.read_text("utf-8")
     assert ca_cert in cacerts
 
-    ca_key = docker_git_certs.ca_private_key.read_text("utf-8")
+    ca_key = git_certs.ca_private_key.read_text("utf-8")
     assert ca_key not in cacerts
 
-    cert = docker_git_certs.certificate.read_text("utf-8")
+    cert = git_certs.certificate.read_text("utf-8")
     assert cert not in cacerts
 
-    key = docker_git_certs.private_key.read_text("utf-8")
+    key = git_certs.private_key.read_text("utf-8")
     assert key not in cacerts
 
 
-def test_docker_git_cacerts_list(
-    docker_git_cacerts_list: List[Path],
-    docker_git_certs_list: List[DockerGITCerts],
-    pdrf_scale_factor: int,
+def test_git_cacerts_list(
+    git_cacerts_list: List[Path],
+    git_certs_list: List[GITCerts],
+    pdgf_scale_factor: int,
 ):
     """Test that a temporary CA certificate trust store can be provided."""
-    for i in range(pdrf_scale_factor):
-        assert docker_git_cacerts_list[i].exists()
-        cacerts = docker_git_cacerts_list[i].read_text("utf-8")
+    for i in range(pdgf_scale_factor):
+        assert git_cacerts_list[i].exists()
+        cacerts = git_cacerts_list[i].read_text("utf-8")
 
-        ca_cert = docker_git_certs_list[i].ca_certificate.read_text("utf-8")
+        ca_cert = git_certs_list[i].ca_certificate.read_text("utf-8")
         assert ca_cert in cacerts
 
-        ca_key = docker_git_certs_list[i].ca_private_key.read_text("utf-8")
+        ca_key = git_certs_list[i].ca_private_key.read_text("utf-8")
         assert ca_key not in cacerts
 
-        cert = docker_git_certs_list[i].certificate.read_text("utf-8")
+        cert = git_certs_list[i].certificate.read_text("utf-8")
         assert cert not in cacerts
 
-        key = docker_git_certs_list[i].private_key.read_text("utf-8")
+        key = git_certs_list[i].private_key.read_text("utf-8")
         assert key not in cacerts
-    assert no_duplicates(docker_git_cacerts_list)
-    assert no_duplicates(docker_git_certs_list)
+    assert no_duplicates(git_cacerts_list)
+    assert no_duplicates(git_certs_list)
 
 
-def test_docker_git_certs(docker_git_certs: DockerGITCerts):
+def test_git_certs(git_certs: GITCerts):
     """Test that a certificate and private key can be provided."""
-    assert docker_git_certs.ca_certificate.exists()
-    assert "BEGIN CERTIFICATE" in docker_git_certs.ca_certificate.read_text("utf-8")
-    assert docker_git_certs.ca_private_key.exists()
-    assert "BEGIN PRIVATE KEY" in docker_git_certs.ca_private_key.read_text("utf-8")
-    assert docker_git_certs.certificate.exists()
-    assert "BEGIN CERTIFICATE" in docker_git_certs.certificate.read_text("utf-8")
-    assert docker_git_certs.private_key.exists()
-    assert "BEGIN PRIVATE KEY" in docker_git_certs.private_key.read_text("utf-8")
+    assert git_certs.ca_certificate.exists()
+    assert "BEGIN CERTIFICATE" in git_certs.ca_certificate.read_text("utf-8")
+    assert git_certs.ca_private_key.exists()
+    assert "BEGIN PRIVATE KEY" in git_certs.ca_private_key.read_text("utf-8")
+    assert git_certs.certificate.exists()
+    assert "BEGIN CERTIFICATE" in git_certs.certificate.read_text("utf-8")
+    assert git_certs.private_key.exists()
+    assert "BEGIN PRIVATE KEY" in git_certs.private_key.read_text("utf-8")
 
 
-def test_docker_git_certs_list(
-    docker_git_certs_list: List[DockerGITCerts], pdrf_scale_factor: int
-):
+def test_git_certs_list(git_certs_list: List[GITCerts], pdgf_scale_factor: int):
     """Test that a certificate and private key can be provided."""
-    for i in range(pdrf_scale_factor):
-        assert docker_git_certs_list[i].ca_certificate.exists()
-        assert "BEGIN CERTIFICATE" in docker_git_certs_list[i].ca_certificate.read_text(
+    for i in range(pdgf_scale_factor):
+        assert git_certs_list[i].ca_certificate.exists()
+        assert "BEGIN CERTIFICATE" in git_certs_list[i].ca_certificate.read_text(
             "utf-8"
         )
-        assert docker_git_certs_list[i].ca_private_key.exists()
-        assert "BEGIN PRIVATE KEY" in docker_git_certs_list[i].ca_private_key.read_text(
+        assert git_certs_list[i].ca_private_key.exists()
+        assert "BEGIN PRIVATE KEY" in git_certs_list[i].ca_private_key.read_text(
             "utf-8"
         )
-        assert docker_git_certs_list[i].certificate.exists()
-        assert "BEGIN CERTIFICATE" in docker_git_certs_list[i].certificate.read_text(
-            "utf-8"
-        )
-        assert docker_git_certs_list[i].private_key.exists()
-        assert "BEGIN PRIVATE KEY" in docker_git_certs_list[i].private_key.read_text(
-            "utf-8"
-        )
-    assert no_duplicates(docker_git_certs_list)
+        assert git_certs_list[i].certificate.exists()
+        assert "BEGIN CERTIFICATE" in git_certs_list[i].certificate.read_text("utf-8")
+        assert git_certs_list[i].private_key.exists()
+        assert "BEGIN PRIVATE KEY" in git_certs_list[i].private_key.read_text("utf-8")
+    assert no_duplicates(git_certs_list)
 
 
-def test_docker_git_htpasswd(
-    docker_git_htpasswd: Path,
-    docker_git_password: str,
-    docker_git_username: str,
+def test_git_htpasswd(
+    git_htpasswd: Path,
+    git_password: str,
+    git_username: str,
 ):
     """Test that a htpasswd can be provided."""
-    assert docker_git_htpasswd.exists()
-    content = docker_git_htpasswd.read_text("utf-8")
-    assert docker_git_username in content
-    assert docker_git_password not in content
+    assert git_htpasswd.exists()
+    content = git_htpasswd.read_text("utf-8")
+    assert git_username in content
+    assert git_password not in content
 
 
-def test_docker_git_htpasswd_list(
-    docker_git_htpasswd_list: List[Path],
-    docker_git_password_list: List[str],
-    docker_git_username_list: List[str],
-    pdrf_scale_factor: int,
+def test_git_htpasswd_list(
+    git_htpasswd_list: List[Path],
+    git_password_list: List[str],
+    git_username_list: List[str],
+    pdgf_scale_factor: int,
 ):
     """Test that a htpasswd can be provided."""
-    for i in range(pdrf_scale_factor):
-        assert docker_git_htpasswd_list[i].exists()
-        content = docker_git_htpasswd_list[i].read_text("utf-8")
-        assert docker_git_username_list[i] in content
-        assert docker_git_password_list[i] not in content
-    assert no_duplicates(docker_git_htpasswd_list)
-    assert no_duplicates(docker_git_password_list)
-    assert no_duplicates(docker_git_username_list)
+    for i in range(pdgf_scale_factor):
+        assert git_htpasswd_list[i].exists()
+        content = git_htpasswd_list[i].read_text("utf-8")
+        assert git_username_list[i] in content
+        assert git_password_list[i] not in content
+    assert no_duplicates(git_htpasswd_list)
+    assert no_duplicates(git_password_list)
+    assert no_duplicates(git_username_list)
 
 
-@pytest.mark.create_repo("test_docker_git_insecure")
+@pytest.mark.create_repo("test_git_insecure")
 @pytest.mark.mirror_repo("https://github.com/crashvb/shim-bind.git")
-def test_docker_git_insecure(docker_git_insecure: DockerGITInsecure, tmp_path: Path):
+def test_git_insecure(git_insecure: GITInsecure, tmp_path: Path):
     """Test that an insecure docker git can be instantiated."""
-    assert "127.0.0.1" in docker_git_insecure.endpoint
+    assert "127.0.0.1" in git_insecure.endpoint
 
-    uri_insecure = f"http://{docker_git_insecure.endpoint}/insecure/shim-bind.git"
-    uri_secure = f"http://{docker_git_insecure.endpoint}/secure/shim-bind.git"
+    uri_insecure = f"http://{git_insecure.endpoint}/insecure/shim-bind.git"
+    uri_secure = f"http://{git_insecure.endpoint}/secure/shim-bind.git"
 
     # Should not be able to clone from secure w/o credentials ...
     path = tmp_path.joinpath(f"cloned-repo-{time()}")
@@ -271,29 +233,25 @@ def test_docker_git_insecure(docker_git_insecure: DockerGITInsecure, tmp_path: P
 
 
 @pytest.mark.online
-def test_docker_git_insecure_list(
-    docker_git_insecure_list: List[DockerGITInsecure],
-    pdrf_scale_factor: int,
+def test_git_insecure_list(
+    git_insecure_list: List[GITInsecure],
+    pdgf_scale_factor: int,
     tmp_path: Path,
 ):
     """Test that an insecure docker git can be instantiated."""
-    for i in range(pdrf_scale_factor):
-        assert "127.0.0.1" in docker_git_insecure_list[i].endpoint
+    for i in range(pdgf_scale_factor):
+        assert "127.0.0.1" in git_insecure_list[i].endpoint
 
         # Default listener ...
-        response = requests.get(f"http://{docker_git_insecure_list[i].endpoint}/")
+        response = requests.get(f"http://{git_insecure_list[i].endpoint}/")
         assert response.status_code == 200
         assert response.content == b"pytest-docker-git-fixtures-docker\n"
 
         if i > 0:
             continue
 
-        uri_insecure = (
-            f"http://{docker_git_insecure_list[i].endpoint}/insecure/shim-bind.git"
-        )
-        uri_secure = (
-            f"http://{docker_git_insecure_list[i].endpoint}/secure/shim-bind.git"
-        )
+        uri_insecure = f"http://{git_insecure_list[i].endpoint}/insecure/shim-bind.git"
+        uri_secure = f"http://{git_insecure_list[i].endpoint}/secure/shim-bind.git"
 
         # Should not be able to clone from secure w/o credentials ...
         path = tmp_path.joinpath(f"cloned-repo-{time()}")
@@ -339,35 +297,33 @@ def test_docker_git_insecure_list(
                 stderr=subprocess.STDOUT,
             )
         assert "returned non-zero exit status" in str(exception.value)
-    assert no_duplicates([str(i) for i in docker_git_insecure_list])
+    assert no_duplicates([str(i) for i in git_insecure_list])
 
 
-def test_docker_git_password(docker_git_password: str):
+def test_git_password(git_password: str):
     """Test that a password can be provided."""
-    assert docker_git_password
+    assert git_password
 
 
-def test_docker_git_password_list(
-    docker_git_password_list: List[str], pdrf_scale_factor: int
-):
+def test_git_password_list(git_password_list: List[str], pdgf_scale_factor: int):
     """Test that a password can be provided."""
-    for i in range(pdrf_scale_factor):
-        assert docker_git_password_list[i]
-    assert no_duplicates(docker_git_password_list)
+    for i in range(pdgf_scale_factor):
+        assert git_password_list[i]
+    assert no_duplicates(git_password_list)
 
 
-@pytest.mark.create_repo("test_docker_git_secure")
+@pytest.mark.create_repo("test_git_secure")
 @pytest.mark.mirror_repo("https://github.com/crashvb/scratch-docker.git")
-def test_docker_git_secure(
-    docker_git_secure: DockerGITSecure,
+def test_git_secure(
+    git_secure: GITSecure,
     tmp_path: Path,
     tmp_path_factory: TempPathFactory,
 ):
     """Test that an secure docker git can be instantiated."""
-    assert "127.0.0.1" in docker_git_secure.endpoint
+    assert "127.0.0.1" in git_secure.endpoint
 
-    uri_insecure = f"https://{docker_git_secure.endpoint}/insecure/scratch-docker.git"
-    uri_secure = f"https://{docker_git_secure.endpoint}/secure/scratch-docker.git"
+    uri_insecure = f"https://{git_secure.endpoint}/insecure/scratch-docker.git"
+    uri_secure = f"https://{git_secure.endpoint}/secure/scratch-docker.git"
 
     # Should be able to clone from insecure w/o credentials ...
     path = tmp_path.joinpath(f"cloned-repo-{time()}")
@@ -375,7 +331,7 @@ def test_docker_git_secure(
         [
             "git",
             "-c",
-            f"http.sslCAinfo={docker_git_secure.cacerts}",
+            f"http.sslCAinfo={git_secure.cacerts}",
             "clone",
             uri_insecure,
             str(path),
@@ -393,7 +349,7 @@ def test_docker_git_secure(
             [
                 "git",
                 "-c",
-                f"http.sslCAinfo={docker_git_secure.cacerts}",
+                f"http.sslCAinfo={git_secure.cacerts}",
                 "clone",
                 uri_secure,
                 str(path),
@@ -406,12 +362,14 @@ def test_docker_git_secure(
     assert "returned non-zero exit status" in str(exception.value)
     assert not path.exists()
 
-    uri_secure = f"https://{docker_git_secure.username}@{docker_git_secure.endpoint}/secure/scratch-docker.git"
+    uri_secure = (
+        f"https://{git_secure.username}@{git_secure.endpoint}/secure/scratch-docker.git"
+    )
 
     # Should be able to clone from secure w/ credentials ...
     path = tmp_path.joinpath(f"cloned-repo-{time()}")
     with git_askpass_script(
-        tmp_path_factory, password=docker_git_secure.password
+        tmp_path_factory, password=git_secure.password
     ) as askpass_script:
         subprocess.run(
             ["git", "clone", uri_secure, str(path)],
@@ -419,7 +377,7 @@ def test_docker_git_secure(
             cwd=str(tmp_path),
             env={
                 "GIT_ASKPASS": str(askpass_script),
-                "GIT_SSL_CAINFO": docker_git_secure.cacerts,
+                "GIT_SSL_CAINFO": git_secure.cacerts,
                 "GIT_TERMINAL_PROMPT": "0",
             },
             stderr=subprocess.STDOUT,
@@ -435,7 +393,7 @@ def test_docker_git_secure(
             cwd=str(path),
             env={
                 "GIT_ASKPASS": str(askpass_script),
-                "GIT_SSL_CAINFO": docker_git_secure.cacerts,
+                "GIT_SSL_CAINFO": git_secure.cacerts,
                 "GIT_TERMINAL_PROMPT": "0",
             },
             stderr=subprocess.STDOUT,
@@ -443,21 +401,21 @@ def test_docker_git_secure(
 
 
 @pytest.mark.online
-def test_docker_git_secure_list(
-    docker_git_secure_list: List[DockerGITSecure],
-    pdrf_scale_factor: int,
+def test_git_secure_list(
+    git_secure_list: List[GITSecure],
+    pdgf_scale_factor: int,
     tmp_path: Path,
     tmp_path_factory: TempPathFactory,
 ):
     """Test that an secure docker git can be instantiated."""
-    for i in range(pdrf_scale_factor):
-        assert "127.0.0.1" in docker_git_secure_list[i].endpoint
+    for i in range(pdgf_scale_factor):
+        assert "127.0.0.1" in git_secure_list[i].endpoint
 
         # Default listener ...
         response = requests.get(
-            f"https://{docker_git_secure_list[i].endpoint}/",
-            headers=docker_git_secure_list[i].auth_header,
-            verify=str(docker_git_secure_list[i].cacerts),
+            f"https://{git_secure_list[i].endpoint}/",
+            headers=git_secure_list[i].auth_header,
+            verify=str(git_secure_list[i].cacerts),
         )
         assert response.status_code == 200
         assert response.content == b"pytest-docker-git-fixtures-docker\n"
@@ -466,11 +424,9 @@ def test_docker_git_secure_list(
             continue
 
         uri_insecure = (
-            f"https://{docker_git_secure_list[i].endpoint}/insecure/scratch-docker.git"
-        )
-        uri_secure = (
-            f"https://{docker_git_secure_list[i].endpoint}/secure/scratch-docker.git"
+            f"https://{git_secure_list[i].endpoint}/insecure/scratch-docker.git"
         )
+        uri_secure = f"https://{git_secure_list[i].endpoint}/secure/scratch-docker.git"
 
         # Should be able to clone from insecure w/o credentials ...
         path = tmp_path.joinpath(f"cloned-repo-{time()}")
@@ -478,7 +434,7 @@ def test_docker_git_secure_list(
             [
                 "git",
                 "-c",
-                f"http.sslCAinfo={docker_git_secure_list[i].cacerts}",
+                f"http.sslCAinfo={git_secure_list[i].cacerts}",
                 "clone",
                 uri_insecure,
                 str(path),
@@ -496,7 +452,7 @@ def test_docker_git_secure_list(
                 [
                     "git",
                     "-c",
-                    f"http.sslCAinfo={docker_git_secure_list[i].cacerts}",
+                    f"http.sslCAinfo={git_secure_list[i].cacerts}",
                     "clone",
                     uri_secure,
                     str(path),
@@ -510,14 +466,14 @@ def test_docker_git_secure_list(
         assert not path.exists()
 
         uri_secure = (
-            f"https://{docker_git_secure_list[i].username}@"
-            f"{docker_git_secure_list[i].endpoint}/secure/scratch-docker.git"
+            f"https://{git_secure_list[i].username}@"
+            f"{git_secure_list[i].endpoint}/secure/scratch-docker.git"
         )
 
         # Should be able to clone from secure w/ credentials ...
         path = tmp_path.joinpath(f"cloned-repo-{time()}")
         with git_askpass_script(
-            tmp_path_factory, password=docker_git_secure_list[i].password
+            tmp_path_factory, password=git_secure_list[i].password
         ) as askpass_script:
             subprocess.run(
                 ["git", "clone", uri_secure, str(path)],
@@ -525,7 +481,7 @@ def test_docker_git_secure_list(
                 cwd=str(tmp_path),
                 env={
                     "GIT_ASKPASS": str(askpass_script),
-                    "GIT_SSL_CAINFO": docker_git_secure_list[i].cacerts,
+                    "GIT_SSL_CAINFO": git_secure_list[i].cacerts,
                     "GIT_TERMINAL_PROMPT": "0",
                 },
                 stderr=subprocess.STDOUT,
@@ -541,39 +497,69 @@ def test_docker_git_secure_list(
                 cwd=str(path),
                 env={
                     "GIT_ASKPASS": str(askpass_script),
-                    "GIT_SSL_CAINFO": docker_git_secure_list[i].cacerts,
+                    "GIT_SSL_CAINFO": git_secure_list[i].cacerts,
                     "GIT_TERMINAL_PROMPT": "0",
                 },
                 stderr=subprocess.STDOUT,
             )
 
 
-def test_docker_git_ssl_context(docker_git_ssl_context: SSLContext):
+def test_git_ssl_context(git_ssl_context: SSLContext):
     """Test that an ssl context can be provided."""
-    assert isinstance(docker_git_ssl_context, SSLContext)
+    assert isinstance(git_ssl_context, SSLContext)
 
 
-def test_docker_git_ssl_context_list(
-    docker_git_ssl_context_list: List[SSLContext], pdrf_scale_factor: int
+def test_git_ssl_context_list(
+    git_ssl_context_list: List[SSLContext], pdgf_scale_factor: int
 ):
     """Test that an ssl context can be provided."""
-    for i in range(pdrf_scale_factor):
-        assert isinstance(docker_git_ssl_context_list[i], SSLContext)
-    assert no_duplicates(docker_git_ssl_context_list)
+    for i in range(pdgf_scale_factor):
+        assert isinstance(git_ssl_context_list[i], SSLContext)
+    assert no_duplicates(git_ssl_context_list)
 
 
-def test_docker_git_username(docker_git_username: str):
+def test_git_username(git_username: str):
     """Test that a username can be provided."""
-    assert docker_git_username
+    assert git_username
 
 
-def test_docker_git_username_list(
-    docker_git_username_list: List[str], pdrf_scale_factor: int
+def test_git_username_list(git_username_list: List[str], pdgf_scale_factor: int):
+    """Test that a username can be provided."""
+    for i in range(pdgf_scale_factor):
+        assert git_username_list[i]
+    assert no_duplicates(git_username_list)
+
+
+def test_pdgf_docker_compose_insecure(pdgf_docker_compose_insecure: Path):
+    """Test that the embedded docker-compose for insecure scms can be copied to a temporary file."""
+    service_name = GIT_SERVICE_PATTERN.format("insecure", 0)
+    assert service_name in pdgf_docker_compose_insecure.read_text()
+
+
+def test_pdgf_docker_compose_insecure_list(
+    pdgf_docker_compose_insecure_list: List[Path], pdgf_scale_factor: int
 ):
-    """Test that a username can be provided."""
-    for i in range(pdrf_scale_factor):
-        assert docker_git_username_list[i]
-    assert no_duplicates(docker_git_username_list)
+    """Test that the embedded docker-compose for insecure scms can be copied to a temporary file."""
+    for i in range(pdgf_scale_factor):
+        service_name = GIT_SERVICE_PATTERN.format("insecure", i)
+        assert service_name in pdgf_docker_compose_insecure_list[i].read_text()
+    assert no_duplicates(pdgf_docker_compose_insecure_list)
+
+
+def test_pdgf_docker_compose_secure(pdgf_docker_compose_secure: Path):
+    """Test that the embedded docker-compose for secure scms can be copied to a temporary file."""
+    service_name = GIT_SERVICE_PATTERN.format("secure", 0)
+    assert service_name in pdgf_docker_compose_secure.read_text()
+
+
+def test_pdgf_docker_compose_secure_list(
+    pdgf_docker_compose_secure_list: List[Path], pdgf_scale_factor: int
+):
+    """Test that the embedded docker-compose for secure scms can be copied to a temporary file."""
+    for i in range(pdgf_scale_factor):
+        service_name = GIT_SERVICE_PATTERN.format("secure", i)
+        assert service_name in pdgf_docker_compose_secure_list[i].read_text()
+    assert no_duplicates(pdgf_docker_compose_secure_list)
 
 
 def test__get_create_repo(request):
@@ -583,8 +569,8 @@ def test__get_create_repo(request):
     assert (
         marks.sort()
         == [
-            "test_docker_git_insecure",
-            "test_docker_git_secure",
+            "test_git_insecure",
+            "test_git_secure",
         ].sort()
     )
 
